package edu.chl.hajo.monopoly.core;

import edu.chl.hajo.monopoly.event.Event;
import edu.chl.hajo.monopoly.event.EventBus;

/**
 A single player of the game
 Handles everything that has to do with a single player!

 @author hajo

 */
public class Player {

    // To avoid null as owner of IOwnables
    public static final Player NONE = new Player("none", null, -1);
    private final String name;  // Unique name for player
    //private final Piece piece;

    private int balance;
    private boolean inJail = false;
    private Space position;    // The actual position

    public Player(String name, Piece piece, int balance) {
        this.name = name;
        //this.piece = piece;
        this.balance = balance;
    }

    public Space getPosition() {
        return position;
    }

    public String getName() {
        return name;
    }

    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((name == null) ? 0 : name.hashCode());
        return result;
    }

    @Override
    public boolean equals(Object other) {
        if (this == other) {
            return true;
        }
        if (other == null) {
            return false;
        }
        if (getClass() != other.getClass()) {
            return false;
        }
        Player o = (Player) other;
        return name.equals(o.name);
    }

    public void income(int amont) {
        setBalance(balance + amont);
    }

    public int getBalance() {
        return balance;
    }

    public boolean isInJail() {
        return inJail;
    }

    // Event setters -----------------------
    public void setBalance(int balance) {
        this.balance = balance;
        EventBus.BUS.publish(new Event(Event.Tag.PLAYER_BALANCE, this));
    }

    public void setInJail(boolean b) {
        inJail = b;
        EventBus.BUS.publish(new Event(Event.Tag.PLAYER_IN_JAIL, this));
    }

    public void setPosition(Space position) {
        this.position = position;
        EventBus.BUS.publish(new Event(Event.Tag.PLAYER_POSITION, this));
    }

}
