package edu.chl.hajo.monopoly.ctrl;

import edu.chl.hajo.monopoly.core.Board;
import edu.chl.hajo.monopoly.core.Dices;
import edu.chl.hajo.monopoly.core.Monopoly;
import edu.chl.hajo.monopoly.core.Player;
import edu.chl.hajo.monopoly.core.Space;
import edu.chl.hajo.monopoly.core.Street;
import edu.chl.hajo.monopoly.service.file.FileHandler;
import edu.chl.hajo.monopoly.service.file.IFileHandler;
import edu.chl.hajo.monopoly.view.GameOptions;
import edu.chl.hajo.monopoly.view.MainWindow;
import edu.chl.hajo.monopoly.view.GUIResources;
import java.io.IOException;
import java.util.ArrayList;
import java.util.List;
import javax.swing.JOptionPane;

/**

 @author hajo
 */
public class StartCtrl {

    private final MainWindow mainWindow;

    public StartCtrl(MainWindow mainWindow) {
        this.mainWindow = mainWindow;
    }

    public void execute() {
        List<String> playerNames = GameOptions.getPlayerNames();
        List<String> spaceNames = GameOptions.getSpaceNames();
        List<Space> spaces = getSpaces(spaceNames);
        List<Player> players = getPlayers(playerNames);
        Board board = new Board(spaces);
        Dices dices = new Dices();
        Monopoly monopoly = new Monopoly(players, board, dices);
        // This could be better (higer level for IFilehandler)
        try {
            IFileHandler f = FileHandler.getFileHandler();
            GUIResources.init(f, playerNames);
        } catch (IOException e) {
            JOptionPane.showMessageDialog(mainWindow, "Failed to load game resource");
            return;
        }
        mainWindow.createGamePanel(monopoly);
        monopoly.init();
    }

    public static List<Space> getSpaces(List<String> names) {
        List<Space> sps = new ArrayList<>();
        for (String name : names) {
            // TODO Name starts with number, a street
            if ("123456789".indexOf(name.charAt(0)) >= 0) {
                sps.add(new Street(name, Board.BASIC_RENT));
            } else {
                sps.add(new Space(name));
            }
        }
        return sps;
    }

    public static List<Player> getPlayers(List<String> names) {
        List<Player> sps = new ArrayList<>();
        int i = 0;
        for (String name : names) {
            sps.add(new Player(name, Monopoly.BALANCE));
            i++;
        }
        return sps;
    }
}
