package edu.chl.hajo.monopoly.service.file;

import java.awt.Image;
import java.io.File;
import java.io.IOException;
import java.nio.charset.StandardCharsets;
import java.util.List;
import java.util.logging.Level;
import java.util.logging.Logger;
import javax.imageio.ImageIO;
import javax.swing.ImageIcon;
import org.apache.commons.io.IOUtils;

/**

 @author hajo
 */
public class FileHandler implements IFileHandler {

    private FileHandler() {
    }

    private static IFileHandler handler;

    // Factory method (singleton)
    public static IFileHandler getFileHandler() {
        if (handler == null) {
            handler = new FileHandler();
        }
        return handler;
    }

    // Get an icon from file    
    @Override
    public Image getIcon(String fileName) throws IOException {
        ClassLoader classLoader = getClass().getClassLoader();
        File file = new File(classLoader.getResource("icon/" + fileName).getFile());
        Image i = new ImageIcon(ImageIO.read(file)).getImage();
        return i;
    }

    @Override
    public List<String> getDirectoryFileList(String directory) throws IOException {
        // Uses Apache Commons IO
        List<String> files = IOUtils.readLines(FileHandler.class.getClassLoader()
                .getResourceAsStream(directory + "/"), StandardCharsets.UTF_8.name());
        return files;
    }

    @Override
    public Image getImage(String pathAndfileName) throws IOException {
        ClassLoader classLoader = getClass().getClassLoader();
        File file = new File(classLoader.getResource(pathAndfileName).getFile());
        Image i = new ImageIcon(ImageIO.read(file)).getImage();
        return i;

    }

}
